export interface Section {
    start: number;
    end: number;
    text: string;
    multiLine: boolean;
}
export declare const ws: RegExp;
export declare const nl: string;
/**
 * Retrieves a section of text from the given input text string.  It starts at
 * the given position and works forward/backward through the string looking for
 * newline characters.  The search threshold for the number of lines in each
 * direction is set by the lines parameter.  When the number of newlines, in a
 * direction is found, then the start/end position offsets from the text buffer
 * are found.
 *
 * Setting the `lines` to 0 will just retrieve the current line.
 *
 * @param text {string} the base text string to extract the substring
 * @param pos {number} the starting position within the text string to start
 * looking for newlines.
 * @param lines {number} the number of lines above and below the start position
 * line to include (this number is *2).  e.g. 5, would have five lines above,
 * five lines below, and the line the cursor is on (11 total).
 * @param threshold {number} if the size of the buffer is below this number
 * then just return the whole buffer (don't search when under threshold)
 * @return {Section} an object that represents the section found.  This contains
 * the absolute start/end of the section, and a reference to this section.
 */
export declare function section(text: string, pos: number, lines?: number, threshold?: number): Section;
/**
 * Retrieves the current full line from the given input text.  This uses the
 * newline character from the operating system to determine the beginning and
 * end of the line.  The function is syntactic sugar for the section function.
 * @param text {string} the block of text to perform the search.
 * @param pos {number} the current absolute position within the text block
 * @return {Section} an object that represents the section found.  This contains
 * the absolute start/end of the line, and a reference to this line.
 */
export declare function line(text: string, pos: number): Section;
/**
 * This call will retrieve the current word at the given cursor location.  A
 * word is considered an alphanumeric value surrounded by white space.
 * @param text {string} the block of text to perform the search.
 * @param pos {number} the current absolute position within the text block
 * @return {Section} an object that represents the section found.  This contains
 * the absolute start/end of the word, and a reference to this word.
 */
export declare function word(text: string, pos: number): Section;
